package at.jku.ssw.graph;

/** An edge of a graph. */
public class Edge implements Cloneable {

	public enum Kind {
		Directed, Undirected
	}

	public final Vertex start;
	public final Vertex end;
	public final int weight;
	public final Kind kind;

	/** Creates a directed edge. */
	public Edge(Vertex start, Vertex end) {
		this(start, end, Kind.Directed);
	}

	/** Creates an edge with the specified kind, directed or undirected. */
	public Edge(Vertex start, Vertex end, Kind kind) {
		this(start, end, 0, kind);
	}

	/**
	 * Creates an edge with the specified weight and kind (directed or
	 * undirected).
	 */
	public Edge(Vertex start, Vertex end, int weight, Kind kind) {
		this.start = start;
		this.end = end;
		this.weight = weight;
		this.kind = kind;
	}

	@Override
	public Edge clone() {
		return new Edge(start, end, weight, kind);
	}

	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append(start);
		if (kind == Kind.Directed) {
			sb.append(" -> ");
		} else {
			sb.append(" -- ");
		}
		sb.append(end);
		return sb.toString();
	}

}
